#
# spec file for package teeworlds
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           teeworlds
Version:        0.7.5
Release:        bp153.1.17
Summary:        A retro multiplayer jump-and-swing shooter
License:        Zlib AND CC-BY-SA-3.0
Group:          Amusements/Games/Action/Arcade
URL:            http://www.teeworlds.com
Source:         %{name}-%{version}.tar.xz
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  dejavu-fonts
BuildRequires:  fdupes
BuildRequires:  fontpackages-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libopenssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pnglite-devel
BuildRequires:  python
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(zlib)
Requires:       dejavu-fonts
Provides:       teewars = %{version}
Obsoletes:      teewars < 0.4.0

%description
Teeworlds is an online multiplayer game. Battles can be played with
up to 16 players in a variety of game modes, including Team
Deathmatch and Capture The Flag. Own maps can be designed.

%prep
%setup -q

# we use system libs instead
rm -r src/engine/external/{pnglite,wavpack,zlib}

# Fix line-endings
sed -i 's/\r$//' readme.md

%build
%cmake

%install
%cmake_install
install -D -m 0644 other/teeworlds.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
index=0
for res in 256 128 48 32 24 16; do
    install -d "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps"
    convert -strip "other/icons/teeworlds.ico[$index]" "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps/%{name}.png"
    index=$((index+1))
done
%suse_update_desktop_file %{name}
install -D -m 0644 other/teeworlds.appdata.xml %{buildroot}%{_datadir}/appdata/teeworlds.appdata.xml

# Unbundle DejaVu font
rm -rf %{buildroot}%{_datadir}/%{name}/data/fonts/*
ln -s %{_ttfontsdir}/DejaVuSans.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/DejaVuSans.ttf

%fdupes -s %{buildroot}/%{_datadir}/%{name}

%if 0%{?suse_version} < 1330
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%license license.txt
%doc readme.md
%{_bindir}/teeworlds
%{_bindir}/teeworlds_srv
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Thu Apr 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.5 fixes the following issues:
  Security
  * CVE-2020-12066: denial of service against server (boo#1170252)
  * CVE-2019-20787: integer overflow when computing a tilemap size
    (boo#1170253)
  Server
  * Fix laser bounce delay when server runs for a very long time
  * Rename tune_dump to tunes
  Client
  * Improve client loading
  * Add an option to turn off whispers
  * Server browser
    + store password of favorites
    + improve looks of the friends tab
    + quick search now also matches gametypes
    + some fixes
  * Chat commands
    + add autocompletion hint
    + add descriptions to server-side commands
    + remove the chat command limit
    + some fixes
  * Sliders
    + logarithmic scales
    + move to mouse position on click
    + some fixes
  * Fix statboard not closing with Escape
  * Fix double binds
  * Fix the warmup overlapping with MOTD/scoreboards
  * Fix spectator HUD not rendering in some cases
  * A fix to the menus music
  * A fix to double binds
  + Some fixes to the demo player
  + Rename dump_binds to binds
  Graphics
  * A fix to jungle_background
  * A fix to jungle_midground
  Editor
  * Add automapper for jungle_deathtiles
  * Add mapres preview
  * Show current quad when pressing space in editor
  * Fix a crash
  Maps
  * Some minor bugfixes to ctf5 and dm7
* Wed Dec 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.4
  Highlights from this release:
  * Race mode integration (client side)
  * In-game server browser
  * Chat pages & upgrades
  * Statboard upgrade
  * Winter background theme
  * Wide menus mode
  * Server-side chat commands integration
  * 24 new skins, colorable eyes, and many more body parts to use
* Mon Apr 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.3.1
  * fixed using correct array measurements when placing egg doodads
  * fixed demo recorder downloaded maps using the sha256 hash
  * show correct game release version in the start menu and console
  * Fix platform-specific client libraries for Linux
* Thu Apr 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.3
- Use cmake instead of the bam build-system
- Drop not longer needed patches:
  * bam-0.5.patch
  * desktop.patch
  * teeworlds-0.6.0-datadir.patch
  * teeworlds-0.6.4-extlibs-optflags.patch
- Changes since 0.7.2
  * advanced scoreboard with game statistics
  * joystick support (experimental!)
  * copy paste (one-way)
  * bot cosmetics (a visual difference between players and NPCs)
  * chat commands (type / in chat)
  * players can change skin without leaving the server (again)
  * live automapper and complete rules for 0.7 tilesets
  * audio toggling HUD
  * an Easter surprise...
- Changes since 0.7.1
  Features:
  * Christmas special update.
  * Colorful gametype and level icons in the browser instead of
    grayscale.
  * Add an option to use raw mouse inputs, revert to (0.6) relative
    mode by default.
  * Demo list marker indicator.
  * Restore ingame Player and Tee menus, add a warning that a
    reconnect is needed.
  * Emotes can now be cancelled by releasing the mouse in the
    middle of the circle.
  * Improve add friend text.
  * Add a confirmation for removing a filter
  * Add a "click a player to follow" hint
  * Also hint players which key they should press to set themselves
    ready.
  Fixes:
  * Fixed textures for older graphic cards
  * Cancel whisper when target leaves
  * Fixed server browser entry text color & close region
  * Adjust chat messages to not display UID when option is turned off
  * Fix empty vote when joining a server
  * Broadcast: parse new line character
  * Fix general menu NumOptions
  * Fix failure to open configs in absolute paths since 0.7
  * Fix MOTD not always displayed
  * Adjust volume label size
  * Fix invalid serverinfo
  * Fix red UID background in DM
  * Fix sorting to sort by real players/clients
  * Fix can't remove clan friend
  * Fix too small 0.7 server popups
  * Fix server browser flickering
  * Fix change_map command not always changing map
  * Fix round score reset
  * Properly blend UID in chat
  * Add difficulty info to the ingame menus
- Changes since 0.7.0
  General
  * new gametypes: "last man standing" (LMS) and "last team standing"
    (LTS). survive by your own or as a team with limited weaponry
  * 64 players support. official gametypes are still restricted to 16
    players maximum but allow more spectators
  * new skin system. build your own skins based on a variety of
    provided parts
  * enhanced security. all communications require a handshake and use
    a token to counter spoofing and reflection attacks
  * new maps: ctf8, dm3, lms1. Click to discover them!
  Client
  * animated background menu map: jungle, heavens (day/night themes,
    customisable in the map editor)
  * new design for the menus: added start menus, reworked server
    browser, settings
  * customisable gametype icons (browser). make your own!
  * chat overhaul, whispers (private messages)
  * composed binds (ctrl+, shift+, alt+)
  * scoreboard remodelled, now shows kills/deaths
  * demo markers
  * master server list cache (in case the masters are unreachable)
  * input separated from rendering (optimisation)
  * upgrade to SDL2. support for multiple monitors, non-english
    keyboards, and more
  * 10 new languages
  Server
  * broadcasts overhaul, optional colours support
  * ready system, for competitive settings
  * server difficulty setting (casual, competitive, normal), shown in
    the browser
  * spectator mode improvements: follow flags, click on players
  * bot flags for modified servers: indicate NPCs, can be filtered out
    in the server browser
  * Graphics
  * sharper graphics all around (no more tileset_borderfix and dilate)
  * refreshed the HUD, ninja cooldown, new mouse cursor
  * mapres update (higher resolution, fixes...)
* Mon Apr 16 2018 antoine.belvire@opensuse.org
- Allow build with bam >= 0.5.0.
* Tue May  2 2017 bwiedemann@suse.com
- Use convert -strip to not have timestamps in png files
  to make build more reproducible
* Sat Nov 19 2016 mailaender@opensuse.org
- Update to version 0.6.4
  * Fix attacker controlled memory-writes and possibly arbitrary code execution security vulnerability in the client.
  * Fix a read of uninitialized memory that is sent over the network, from the server.
  * Fix decoding of overlong UTF-8 sequences to non-invalid code points, leading to possible duplicate names.
  * Drop connected packets that come from a formerly connected server in the client.
  * Use a different port for connless messages, increasing the difficulty of successful IP spoofing.
  * Make spoofing of server info packets harder.
  * Fix spoofing for vital chunks, and require most chunks to be vital.
  * Sort by player count by default, instead of server name.
  * Add a cooldown on unpause.
- Drop patches applied upstream
  * fix-server-vulnerability.patch
  * round.patch
- Unbundle DejaVu font
* Sat Nov  5 2016 rpm@fthiessen.de
- Fixed line endings of readme and license
* Sat Nov  5 2016 jengelh@inai.de
- Update descriptions
* Sat Jul 30 2016 mailaender@opensuse.org
- unbundle bam
- build with system libraries
- submitted the .desktop file upstream
- add an appdata.xml file (submitted for upstream inclusion)
- add round.patch to fix the build with C++ 6
* Fri Jul 29 2016 rpm@fthiessen.de
- Added fix-server-vulnerability.patch
- Replaced teeworlds.png with bundled icon.
* Sat Jan 24 2015 Mathias.Homann@opensuse.org
- Update to 0.6.3
  * Fix CVE-2014-9351 in all 0.6.x servers.
  * Fix server crash in the console code.
  * Fix master server lookup for servers.
  * Fix scripts/make_release.py script.
  * Fix client crash when opening a map with an invalid version.
* Sat May  4 2013 mailaender@opensuse.org
- Update to 0.6.2
- Switch to https://en.opensuse.org/SourceUrls
* Sun Jan 20 2013 mailaender@opensuse.org
- add license for assets
- SPDX license tags
* Sun Jan 20 2013 joop.boonen@opensuse.org
- zlib-devel and freefonts2-devel are not an auto BuildRequiment
  any more in openSUSE > 12.1
- Cleaned the spec file up
* Sun Aug  7 2011 PVince81@opensuse.org
- Updated to 0.6.1
* Sat Apr 16 2011 PVince81@opensuse.org
- Updated to 0.6.0
* Thu Mar  4 2010 adam@mizerski.pl
- Fixed no-return-in-nonvoid-function src/tools/crapnet.cpp:203
- Tagged paches
* Thu Mar  4 2010 adam@mizerski.pl
- Updated to 0.5.2
  * Fixed server flood crash
  * A bunch of smaller fixes
  * Fixed a couple of compiler warnings
* Mon Oct 12 2009 prusnak@suse.cz
- moved data to /usr/share and binaries to /usr/bin
* Thu Jan 29 2009 prusnak@suse.cz
- updated to 0.5.1
  * Hook sound fixed
  * Prediction and game timer fixed so the game should be a lot smoother now
  * Server filter that filters out non-standard maps
  * General improvements of the server browser
  * VSync fixed
  * Increased voting time from 10 seconds to 25
  * Scoreboard now works with 16 players
  * Fixed so you can't by-pass the server password
  * Tab completion and command help in the console
  * More various small fixes
* Thu Jan 15 2009 cmorve69@yahoo.es
- updated to 0.5.0
  * General
  - Demo recording and playback
  - Support for up to 16 players
  - Network and bandwidth reduction fixes
  - Some changes to better acommodate unofficial mods. Note: Mods are still
    unsupported.
  - Improved server browser: extended server info, better filtering, support
    for favorite servers
  - Server browser now has an option to filter out modded or tweaked servers,
    showing only "pure" servers. This option is enabled by default.
  - Ban support
  - Voting is now fully implemented. Admins decide what server setting can be
    voted on.
  - Support for death and non-hookable tiles
  - Move from glfw+portaudio to SDL
  - Game balance fixes
  * Maps and tilesets
  - Map pack has been updated, including six new maps (3x DM, 3x CTF)
  - Tilesets have been updated, jungle tileset added. Check your maps!
  - Non-hookable tiles (represented by new graphics)
  - Death tiles
* Mon Sep  1 2008 prusnak@suse.cz
- updated to 0.4.3
  * Auto team balance
  * Anti-spam fixes
  * Fixed editor crash on windows when saving
  * Added clear collision to the editor
  * Fixed issue with cursor being hidden on some maps
  * New version notifier
  * Silent mode for windows
  * F10 for screenshots now works in the editor
* Sun Apr 27 2008 prusnak@suse.cz
- add desktop and icon file
* Tue Apr 22 2008 prusnak@suse.cz
- build with %%optflags
* Tue Apr  8 2008 prusnak@suse.cz
- updated to 0.4.2
  * Loads of graphical optimizations. Maps now must have
    a background to behave correctly. Enable gfx_clear to get around
    faulty maps ("gfx_clear 1" in the console).
  * Fixed the welcome screen overlapping
  * sv_powerups now work again
  * Weapon switch have priority over fire now
  * Added sv_rounds_per_map to control the rounds played on each map
  * Fixed servere memory leak on linux server builds
  * Fixed issue with ping on LAN servers
  * Fixed problems with dm6 and low detail and made shotgun more visible
  * Improved the quicksearch so it's case insenitive, searches players
    aswell and highlights hits
  * Fixed server crash if you try to run ctf on a non ctf map
  * Fixed so you can't set mouse sens to 0 in the gui
  * Fixed "sample bleeding" on the blue flag
  * Fixed so say_team when you are a spectator only sends to other spectators.
  * Fixed problem with maps with 1 thick tile borders
  * Fixed so the loading text doesn't disappear if you move the mouse.
  * Added option to set the time MOTD is displayed (cl_motd_time)
  * MOTD disappears if you press escape
  * Fixed so you can do more advanced binds using "
  * Fixed so you can clear string variables by using ""
  * Fixed skidsmoke errors
  * Fixed so grenades always do 6dmg on direct hit
  * Fixed protection on the font textures so they don't get resampled
  * Added # comments to the console system
  * Added anti-spam function (sv_spamprotection)
  * Fixed so that new line correctly realigns to screen
* Wed Mar 26 2008 prusnak@suse.cz
- fixed strict aliasing (aliasing.patch)
* Wed Mar 26 2008 prusnak@suse.cz
- updated to 0.4.1
  * Added "Reset Filter" button
  * Added support for autoexec.cfg
  * Added support for spectator slots
  * Improved the MOTD
  * Made the double jump indicator more suddle
  * Fixed the shooting through walls bug
  * Fixed the detail levels of dm6
  * Fixed issue with contrasts when using custom colors
  * Fixed so maps downloads to $USER/maps
  * Fixed weapon switching bugs
  * Fixed the password entry when joining servers
  * Fixed problems with binds. Please press the "Reset to defaults" when upgrading
  * Fixed problem when player becomes spectator and holding the flag
  * Various other small fixes
* Wed Mar 26 2008 prusnak@suse.cz
- NAME CHANGE: from teewars to teeworlds (upstream change)
- updated to 0.4.0
  * Reduced latency
  * New console
  * New font system
  * New map editor
  * Graphical updates
  * Automatic downloading of maps
  * Added security
  * New binds system
  * Loads of other updates!
* Fri Feb 15 2008 prusnak@suse.cz
- copied from home:civ75
- updated to 0.3.4
- include bam building tool (svn-r117)
- put binaries in /usr/games, change datafiles paths to absolute,
  allowing them to reside in /usr/share/games/teewars (datadir.patch)
